.. _sardana-devel-macro-call-examples:

=========================
Macro call examples
=========================

This chapter consists of a series of examples demonstrating how to call macros
from inside a macro


.. literalinclude:: ../../../../src/sardana/macroserver/macros/examples/submacros.py
   :language: python
   :linenos:
